
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.1.32'
version = '1.1.32'
full_version = '1.1.32'
git_revision = '253ab5ddb9e24f11c7c99f2ad69a6a941dd991ad'
release = True

if not release:
    version = full_version
    short_version += ".dev"
